summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--core/cortex-m/cpu.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/core/cortex-m/cpu.h b/core/cortex-m/cpu.h
index 47c7d0bca1..504a0ca8df 100644
--- a/core/cortex-m/cpu.h
+++ b/core/cortex-m/cpu.h
@@ -72,9 +72,9 @@ void cpu_invalidate_dcache(void);
/* Clean and Invalidate the D-cache to the Point of Coherency */
void cpu_clean_invalidate_dcache(void);
-/* Invalidate a single range of the D-cache */
-void cpu_invalidate_dcache_range(uintptr_t base, unsigned int length);
-/* Clean and Invalidate a single range of the D-cache */
-void cpu_clean_invalidate_dcache_range(uintptr_t base, unsigned int length);
+/* Invalidate a single address of the D-cache */
+void cpu_invalidate_dcache_address(uintptr_t address);
+/* Clean and Invalidate a single address of the D-cache */
+void cpu_clean_invalidate_dcache_address(uintptr_t address);
#endif /* __CROS_EC_CPU_H */